# Upstream Open Issues Snapshot (2026-02-16)

Total open issues (excluding pull requests): 27

| Number | Title | Created | URL |
|---|---|---|---|
| #305 | Depreciated dependency on python 3.12 (numpy.distutils) causes error on import | 2024-12-20 | https://github.com/perrygeo/python-rasterstats/issues/305 |
| #303 | Bug: progress=true consumes the iterator | 2024-09-27 | https://github.com/perrygeo/python-rasterstats/issues/303 |
| #295 | Adding CRS information to output of zonal stats | 2023-10-19 | https://github.com/perrygeo/python-rasterstats/issues/295 |
| #294 | point_query does not always return a value for coordinates at the corner of a pixel bordered by no-data | 2023-10-12 | https://github.com/perrygeo/python-rasterstats/issues/294 |
| #291 | Potential refactor for large speed boost | 2023-08-13 | https://github.com/perrygeo/python-rasterstats/issues/291 |
| #288 | Unclear error handling for shp missing shx/dbf | 2023-04-11 | https://github.com/perrygeo/python-rasterstats/issues/288 |
| #286 | Segmentation Fault (not necessarily caused by memory usage) | 2023-03-12 | https://github.com/perrygeo/python-rasterstats/issues/286 |
| #285 | causes memory overflow in the loop | 2023-03-02 | https://github.com/perrygeo/python-rasterstats/issues/285 |
| #271 | `properties_out` option | 2023-01-15 | https://github.com/perrygeo/python-rasterstats/issues/271 |
| #246 | zonalstats includes numpy masked data areas in stats calculations | 2021-09-21 | https://github.com/perrygeo/python-rasterstats/issues/246 |
| #243 | nodata when geometry has empty rasterization | 2021-05-05 | https://github.com/perrygeo/python-rasterstats/issues/243 |
| #227 | Poor performance for boundless reads | 2020-10-19 | https://github.com/perrygeo/python-rasterstats/issues/227 |
| #215 | zonal_stats function returns 'infinity' value  | 2020-05-06 | https://github.com/perrygeo/python-rasterstats/issues/215 |
| #214 | Using rasterstats with multigeometries on very large datasets | 2020-03-01 | https://github.com/perrygeo/python-rasterstats/issues/214 |
| #208 | handling remote files (or setting rasterio/gdal context) | 2020-01-29 | https://github.com/perrygeo/python-rasterstats/issues/208 |
| #206 | Progress Bar on Zonal_Stats | 2020-01-08 | https://github.com/perrygeo/python-rasterstats/issues/206 |
| #188 | how to filter specified value？ | 2019-05-12 | https://github.com/perrygeo/python-rasterstats/issues/188 |
| #165 | Warning about float dtype | 2018-03-23 | https://github.com/perrygeo/python-rasterstats/issues/165 |
| #157 | benchmark data unavailable | 2017-10-04 | https://github.com/perrygeo/python-rasterstats/issues/157 |
| #133 | Move docs off pythonhosted | 2016-10-01 | https://github.com/perrygeo/python-rasterstats/issues/133 |
| #124 | Question: caching intermediate operations. | 2016-08-31 | https://github.com/perrygeo/python-rasterstats/issues/124 |
| #108 | Don't read raster if geometry bounds don't overlap | 2015-12-23 | https://github.com/perrygeo/python-rasterstats/issues/108 |
| #105 | nodata count includes non-overlapping cells | 2015-12-18 | https://github.com/perrygeo/python-rasterstats/issues/105 |
| #98 | Non-standard affine transforms handled incorrectly | 2015-09-16 | https://github.com/perrygeo/python-rasterstats/issues/98 |
| #97 | netCDF support | 2015-09-16 | https://github.com/perrygeo/python-rasterstats/issues/97 |
| #90 | Rasterization pixel overlap strategy | 2015-09-11 | https://github.com/perrygeo/python-rasterstats/issues/90 |
| #73 | Multiband support | 2015-08-14 | https://github.com/perrygeo/python-rasterstats/issues/73 |
